@@ -24,7 +24,7 @@ next(gen_ret(1))
 #? []
 next(gen_ret()).
 
-# generators evaluate to true if cast by bool.
+# generators infer to true if cast by bool.
 a = ''
 if gen_ret():
     a = 3
@@ -78,6 +78,28 @@ g = iter([1.0])
 #? float()
 next(g)
 
+x, y = Get()
+#? int() str()
+x
+#? int() str()
+x
+
+class Iter:
+    def __iter__(self):
+        yield ""
+        i = 0
+        while True:
+            v = 1
+            yield v
+            i += 1
+a, b, c = Iter()
+#? str() int()
+a
+#? str() int()
+b
+#? str() int()
+c
+
 
 # -----------------
 # __next__
@@ -134,7 +156,7 @@ a, b = simple()
 #? int() str()
 a
 # For now this is ok.
-#?
+#? int() str()
 b
 
 
@@ -220,7 +242,7 @@ def x():
 # yield from
 # -----------------
 
-# python >= 3.3
+# python > 2.7
 
 def yield_from():
     yield from iter([1])
